@@ -139,6 +139,48 @@ class Mapper2:
 
         return self
 
+    def add_mask(self, gdf, masking_location, map_dictionary, background=None, cmap=None, transparency = None, views_experimental_labels = None,  **kwargs):
+
+        #this function creates a mask to overlay over the other things
+        #it is identical to the previous add_layer function
+        #with exception of masking location
+        #please note that you have to use a map_dictionary, as there is only one value so scale must be created
+
+        if masking_location == 'globe':
+            data_to_use = gdf
+        elif masking_location == 'africa':
+            data_to_use = gdf[(gdf['in_africa'] == 1)]
+        elif masking_location == 'ame':
+            data_to_use = gdf[(gdf['in_africa'] == 1) | (gdf['in_me'] == 1)]
+        else:
+            data_to_use = gdf[gdf.index == masking_location]
+
+        if transparency is not None:
+            alpha_value = transparency
+        else:
+            alpha_value = 1
+
+        if "color" in kwargs:
+            colormap = None
+        else:
+            colormap = 'rainbow' if cmap is None else cmap
+
+        Mapper2.add_colorbar(self, colormap, min(map_dictionary.values()), max(map_dictionary.values()), tickparams=map_dictionary, transparency = alpha_value)
+
+        self.ax = data_to_use.plot(ax=self.ax, alpha=alpha_value, cmap=colormap, vmin=min(map_dictionary.values()),
+                           vmax=max(map_dictionary.values()), **kwargs)
+
+        if background is not None:
+            Mapper2.add_background(self, gdf, background)
+
+        if views_experimental_labels is not None:
+            Mapper2.add_views_experimental_labels(self, gdf, views_experimental_labels)
+
+        return self
+
+
+
+
     def add_colorbar(
             self,
             cmap,
@@ -238,4 +280,3 @@ class Mapper2:
 
     def add_views_experimental_labels(self, gdf, font):
         gdf.apply(lambda x: self.ax.annotate(text=x['name'], xy=x.geom.centroid.coords[0], ha='center', size=font, annotation_clip = True, clip_on = True), axis=1)
-
